==> alexaplusunity-0.0.7.tgz: package/README.md <==
# AlexaPlusUnity [![NPM version](https://badge.fury.io/js/alexaplusunity.svg)](https://npmjs.org/package/alexaplusunity)

> The Alexa Plus Unity SDK was built to help with the expansion of Amazon’s Alexa into video games, bringing a whole new layer of immersion into gaming.
> 
> Ready to get started? Follow the guides [here](https://alexaplusunity.readthedocs.io/en/latest/index.html "AlexaPlusUnity Docs") to start!
>
> Works with the AlexaPlusUnity SDK for Unity

## Installation

```sh
$ npm install alexaplusunity
```

## Usage

### Create instance:

1. Require module:
```js
var alexaPlusUnityClass = require('alexaplusunity');
```

2. Create instance of class:
```js
var alexaPlusUnity = alexaPlusUnityClass("<YOUR_PUBNUB_PUB_KEY>", "<YOUR_PUBNUB_SUB_KEY>", true); //Third parameter enables verbose logging
```

### Avaliable methods:

```js
/**
 * Create new AlexaPlusUnity Instance.
 * @constructor
 * @param {string} publishKey - Your PubNub publish key.
 * @param {string} subscribeKey - Your PubNub subscribe key.
 * @param {bool} [debug=false] - True to enable detailed logs.
 */
constructor(publishKey, subscribeKey, debug)
```

```js
/**
* Enable/Disable detailed logs.
* @param {bool} debug - True to enable detailed logs.
*/
setDebug(debug)
```

```js
/**
 * Update PubNub instance.
 * @param {string} publishKey - Your PubNub publish key.
 * @param {string} subscribeKey - Your PubNub subscribe key.
 */
setPubNub(publishKey, subscribeKey)
```

```js
/**
 * Add channel to channel group.
 * @param {string} channel - Channel to add.
 * @param {string} channelGroup - Group to add channel to.
 * 
 * @returns {Promise}
 */
addChannelToGroup(channel, channelGroup)
```

```js
/**
 * Publish message to Unity.
 * @param {string} message - Message to send.
 * @param {string} channel - Channel to send message over.
 * 
 * @returns {Promise}
 */
publishMessage(message, channel)
```

```js
/**
 * Publish message to Unity and listen for response.
 * @param {string} message - Message to send.
 * @param {string} channel - Channel to send message over.
 * @param {number} [timeout=1000] - Listener timeout in milliseconds.
 * 
 * @returns {Promise}
 */
publishMessageAndListenToResponse(message, channel, timeout = 1000)
```

```js
/**
 * List channels in channel group.
 * @param {string} channelGroup - Channel group to find channels in.
 * 
 * @returns {Promise}
 */
listChannels(channelGroup)
```

```js
/**
 * Create and add new unique channel to channel group.
 * @param {string} channelGroup - Channel group create new, unique channel in.
 * 
 * @returns {string}
 */
uniqueQueueGenerator(channelGroup)
```

```js
/**
 * Make new 5 charecter ID.
 * @returns {string}
 */
makeId()
```

## License

ISC © [Austin Wilson](https://github.com/AustinMathuw)

==> alexaplusunity-0.0.9.tgz: package/README.md <==
# Games SDK for Alexa [![NPM version](https://badge.fury.io/js/alexaplusunity.svg)](https://npmjs.org/package/alexaplusunity)

> The Games SDK for Alexa was built to help with the expansion of Amazon’s Alexa into video games, bringing a whole new layer of immersion into gaming.
> 
> Ready to get started? Follow the guides [here](https://games-sdk-for-alexa.readthedocs.io/en/latest/index.html "Games SDK for Alexa Docs") to start!

## Installation

```sh
$ npm install alexaplusunity
```

## Usage

### Create instance:

1. Require module:
```js
var alexaPlusUnityClass = require('alexaplusunity');
```

2. Create instance of class:
```js
var alexaPlusUnity = alexaPlusUnityClass("<YOUR_PUBNUB_PUB_KEY>", "<YOUR_PUBNUB_SUB_KEY>", true); //Third parameter enables verbose logging
```

### Avaliable methods:

```js
/**
 * Create new GamesSDK Instance.
 * @constructor
 * @param {string} publishKey - Your PubNub publish key.
 * @param {string} subscribeKey - Your PubNub subscribe key.
 * @param {bool} [debug=false] - True to enable detailed logs.
 */
constructor(publishKey, subscribeKey, debug)
```

```js
/**
* Enable/Disable detailed logs.
* @param {bool} debug - True to enable detailed logs.
*/
setDebug(debug)
```

```js
/**
 * Update PubNub instance.
 * @param {string} publishKey - Your PubNub publish key.
 * @param {string} subscribeKey - Your PubNub subscribe key.
 */
updatePubNub(publishKey, subscribeKey)
```

```js
/**
 * Add channel to channel group.
 * @param {string} channel - Channel to add.
 * @param {string} channelGroup - Group to add channel to.
 * 
 * @returns {Promise}
 */
addChannelToGroup(channel, channelGroup)
```

```js
/**
 * Publish message to Game Engines.
 * @param {string} message - Message to send.
 * @param {string} channel - Channel to send message over.
 * 
 * @returns {Promise}
 */
publishMessage(message, channel)
```

```js
/**
 * Publish message to Unity and listen for response.
 * @param {string} message - Message to send.
 * @param {string} channel - Channel to send message over.
 * @param {number} [timeout=1000] - Listener timeout in milliseconds.
 * 
 * @returns {Promise}
 */
publishMessageAndListenToResponse(message, channel, timeout = 1000)
```

```js
/**
 * List channels in channel group.
 * @param {string} channelGroup - Channel group to find channels in.
 * 
 * @returns {Promise}
 */
listChannels(channelGroup)
```

```js
/**
 * Create and add new unique channel to channel group.
 * @param {string} channelGroup - Channel group create new, unique channel in.
 * 
 * @returns {string}
 */
uniqueQueueGenerator(channelGroup)
```

```js
/**
 * Make new 5 charecter ID.
 * @returns {string}
 */
makeId()
```

## License

MIT © [Austin Wilson](https://github.com/AustinMathuw)
